<?php

if (! class_exists('bookingpress_customize') ) {
    class bookingpress_customize
    {
        function __construct()
        {
            add_action('bookingpress_customize_dynamic_view_load', array( $this, 'bookingpress_load_customize_dynamic_view_func' ));
            add_action('bookingpress_customize_dynamic_data_fields', array( $this, 'bookingpress_dynamic_data_fields_func' ));
            add_action('bookingpress_customize_dynamic_computed_methods', array( $this, 'bookingpress_dynamic_computed_methods_func' ));
            add_action('bookingpress_customize_dynamic_on_load_methods', array( $this, 'bookingpress_dynamic_onload_methods_func' ));
            add_action('bookingpress_customize_dynamic_vue_methods', array( $this, 'bookingpress_dynamic_vue_methods_func' ));
            add_action('bookingpress_customize_dynamic_components', array( $this, 'bookingpress_dynamic_components_func' ));
            add_action('bookingpress_customize_dynamic_helper_vars', array( $this, 'bookingpress_customize_helper_vars_func' ));

            add_action('wp_ajax_bookingpress_save_field_settings', array( $this, 'bookingpress_save_field_settings_data_func' ));
            add_action('wp_ajax_bookingpress_save_my_booking_settings', array( $this, 'bookingpress_save_my_booking_settings_func' ));
            add_action('wp_ajax_bookingpress_load_field_settings', array( $this, 'bookingpress_load_field_settings_func' ));
            add_action('wp_ajax_bookingpress_update_field_position', array( $this, 'bookingpress_update_field_pos_func' ));
            add_action('wp_ajax_bookingpress_save_form_settings', array( $this, 'bookingpress_save_form_settings_func' ));
            add_action('wp_ajax_bookingpress_load_bookingform_data', array( $this, 'bookingpress_load_bookingform_data_func' ));
            add_action('wp_ajax_bookingpress_load_my_booking_data', array( $this, 'bookingpress_load_my_booking_data_func' ));
        }

        function bookingpress_load_bookingform_data_func()
        {
            global $wpdb, $BookingPress, $tbl_bookingpress_customize_settings, $bookingpress_customize_vue_data_fields;
            $response              = array();
            $wpnonce               = isset($_REQUEST['_wpnonce']) ? sanitize_text_field($_REQUEST['_wpnonce']) : '';
            $bpa_verify_nonce_flag = wp_verify_nonce($wpnonce, 'bpa_wp_nonce');
            if (! $bpa_verify_nonce_flag ) {
                $response['formdata'] = '';
                $response['variant']  = 'error';
                $response['title']    = esc_html__('Error', 'bookingpress-appointment-booking');
                $response['msg']      = esc_html__('Sorry, Your request can not process due to security reason.', 'bookingpress-appointment-booking');
                echo wp_json_encode($response);
                exit;
            }

            $tab_container_data = array(
                'service_title'         => __('Services', 'bookingpress-appointment-booking'),
                'datetime_title'        => __('Date & Time', 'bookingpress-appointment-booking'),
                'basic_details_title'   => __('Basic Details', 'bookingpress-appointment-booking'),
                'summary_title'         => __('Summary', 'bookingpress-appointment-booking'),
            );

            $category_container_data = array(
                'category_title'         => __('Select Category', 'bookingpress-appointment-booking'),
				'all_category_title'         => __( 'ALL', 'bookingpress-appointment-booking' ),
            );

            $service_container_data = array(
                'service_heading_title' => __('Select Service', 'bookingpress-appointment-booking'),
                'default_image_url'     => BOOKINGPRESS_URL . '/images/placeholder-img.jpg',
            );

            $timeslot_container_data = array(
                'timeslot_text'     => __('Time Slot', 'bookingpress-appointment-booking'),            
                'morning_text'      => __('Morning', 'bookingpress-appointment-booking'),            
                'afternoon_text'    => __('Afternoon', 'bookingpress-appointment-booking'),
                'evening_text'      => __('Evening', 'bookingpress-appointment-booking'),            
                'night_text'        => __('Night', 'bookingpress-appointment-booking'),
            );

            $bookingpress_colorpicker_values = array(
                'background_color'         => '#fff',
                'footer_background_color'  => '#f4f7fb',
                'primary_color'            => '#12D488',
                'primary_background_color' => '#e2faf1',
                'label_title_color'        => '#202C45',
                'sub_title_color'          => '#202C45',
                'sub_title_color'          => '#202C45',
                'content_color'            => '#535D71',
                'price_button_text_color'  => '#fff',
                'custom_css'               => '',
            );

            $bookingpress_font_values = array(
                'title_font_family'   => 'Poppins',
            );
            $booking_form_settings = array(
                'hide_category_service_selection' => false,
                'hide_already_booked_slot'        => false,
                'display_service_description'     => false,
                'booking_form_tabs_position'      => 'left',
                'service_duration_label'          => __('Duration', 'bookingpress-appointment-booking') . ':',
                'service_price_label'             => __('Price', 'bookingpress-appointment-booking') . ':',
                'goback_button_text'              => __('Go Back', 'bookingpress-appointment-booking'),
                'next_button_text'                => __('Next', 'bookingpress-appointment-booking'),
                'book_appointment_btn_text'       => __('Book Appointment', 'bookingpress-appointment-booking'),
                'after_booking_redirection'       => '',
                'after_failed_payment_redirection' =>  '',
            );
            $summary_container_data        = array(
                'summary_content_text'          => __('Your appointment booking summary', 'bookingpress-appointment-booking'),
                'payment_method_text'           => __('Select Payment Method', 'bookingpress-appointment-booking'),
            );
            $front_lable_edit_data         = array(
                'paypal_text'                 => __('PayPal', 'bookingpress-appointment-booking'),
                'locally_text'                => __('Pay Locally', 'bookingpress-appointment-booking'),
                'total_amount_text'           => __('Total Amount Payable', 'bookingpress-appointment-booking'),
                'service_text'                => __('Service', 'bookingpress-appointment-booking'),
                'customer_text'               => __('Customer', 'bookingpress-appointment-booking'),
                'date_time_text'              => __('Date & Time', 'bookingpress-appointment-booking'),
            );
            $booking_form_settings         = apply_filters('bookingpress_get_booking_form_customize_data_filter', $booking_form_settings);
            $bookingpress_bookingform_data = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$tbl_bookingpress_customize_settings} WHERE bookingpress_setting_type = %s", 'booking_form'), ARRAY_A); // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared -- Reason: $tbl_bookingpress_customize_settings is table name defined globally. False Positive alarm
            foreach ( $bookingpress_bookingform_data as $bookingpress_formdata_key => $bookingpress_formdata_val ) {
                $bookingpress_setting_name  = $bookingpress_formdata_val['bookingpress_setting_name'];
                $bookingpress_setting_value = stripslashes_deep($bookingpress_formdata_val['bookingpress_setting_value']);

                if ($bookingpress_setting_value == 'false' || $bookingpress_setting_value == 'true' ) {
                    $bookingpress_setting_value = ( $bookingpress_setting_value == 'false' ) ? false : true;
                }

                if (isset($bookingpress_colorpicker_values[ $bookingpress_setting_name ]) ) {
                    $bookingpress_colorpicker_values[ $bookingpress_setting_name ] = $bookingpress_setting_value;
                } elseif (isset($bookingpress_font_values[ $bookingpress_setting_name ]) ) {
                    $bookingpress_font_values[ $bookingpress_setting_name ] = $bookingpress_setting_value;
                } elseif (isset($tab_container_data[ $bookingpress_setting_name ]) ) {
                    $tab_container_data[ $bookingpress_setting_name ] = $bookingpress_setting_value;
                } elseif (isset($category_container_data[ $bookingpress_setting_name ]) ) {
                    $category_container_data[ $bookingpress_setting_name ] = $bookingpress_setting_value;
                } elseif (isset($service_container_data[ $bookingpress_setting_name ]) ) {
                    $service_container_data[ $bookingpress_setting_name ] = $bookingpress_setting_value;
                } elseif (isset($timeslot_container_data[ $bookingpress_setting_name ]) ) {
                    $timeslot_container_data[ $bookingpress_setting_name ] = $bookingpress_setting_value;
                } elseif (isset($booking_form_settings[ $bookingpress_setting_name ]) ) {
                    $booking_form_settings[ $bookingpress_setting_name ] = $bookingpress_setting_value;
                } elseif (isset($summary_container_data[ $bookingpress_setting_name ]) ) {
                    $summary_container_data[ $bookingpress_setting_name ] = $bookingpress_setting_value;
                } elseif (isset($front_lable_edit_data[ $bookingpress_setting_name ]) ) {
                    $front_lable_edit_data[ $bookingpress_setting_name ] = $bookingpress_setting_value;
                }
            }

            $bookingpress_return_data = array(
            'tab_container_data'      => $tab_container_data,
            'category_container_data' => $category_container_data,
            'service_container_data'  => $service_container_data,
            'timeslot_container_data' => $timeslot_container_data,
            'colorpicker_values'      => $bookingpress_colorpicker_values,
            'font_values'             => $bookingpress_font_values,
            'booking_form_settings'   => $booking_form_settings,
            'summary_container_data'  => $summary_container_data,
            'front_lable_edit_data'   => $front_lable_edit_data,
            );

            $response['variant']  = 'success';
            $response['title']    = esc_html__('Success', 'bookingpress-appointment-booking');
            $response['msg']      = esc_html__('Field Settings Data Retrieved Successfully', 'bookingpress-appointment-booking');
            $response['formdata'] = $bookingpress_return_data;

            echo wp_json_encode($response);
            exit();
        }

        function bookingpress_load_my_booking_data_func()
        {

            global $wpdb, $BookingPress, $tbl_bookingpress_customize_settings, $bookingpress_customize_vue_data_fields;
            $response              = array();
            $wpnonce               = isset($_REQUEST['_wpnonce']) ? sanitize_text_field($_REQUEST['_wpnonce']) : '';
            $bpa_verify_nonce_flag = wp_verify_nonce($wpnonce, 'bpa_wp_nonce');
            if (! $bpa_verify_nonce_flag ) {
                $response['formdata'] = '';
                $response['variant']  = 'error';
                $response['title']    = esc_html__('Error', 'bookingpress-appointment-booking');
                $response['msg']      = esc_html__('Sorry, Your request can not process due to security reason.', 'bookingpress-appointment-booking');
                echo wp_json_encode($response);
                exit;
            }       
            $bookingpress_my_booking_field_settings = array(
                'mybooking_title_text'        => __('My Bookings', 'bookingpress-appointment-booking'),
                'hide_customer_details'       => false,
                'hide_search_bar'             => false,
                'allow_to_cancel_appointment' => true,
                'reset_button_title'          => __('Reset', 'bookingpress-appointment-booking'),  
                'apply_button_title'          => __('Apply', 'bookingpress-appointment-booking'),  
                'search_appointment_title'    => __('Search appointments', 'bookingpress-appointment-booking'),  
                'after_cancelled_appointment_redirection' => '',
            );
            $bookingpress_my_booking_field_settings = apply_filters('bookingpress_get_my_booking_customize_data_filter', $bookingpress_my_booking_field_settings);

            $bookingpress_bookingform_data = $wpdb->get_results($wpdb->prepare("SELECT * FROM {$tbl_bookingpress_customize_settings} WHERE bookingpress_setting_type = %s", 'booking_my_booking'), ARRAY_A); // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared -- Reason: $tbl_bookingpress_customize_settings is table name defined globally. False Positive alarm
            foreach ( $bookingpress_bookingform_data as $bookingpress_formdata_key => $bookingpress_formdata_val ) {
                $bookingpress_setting_name  = $bookingpress_formdata_val['bookingpress_setting_name'];
                $bookingpress_setting_value = $bookingpress_formdata_val['bookingpress_setting_value'];

                if ($bookingpress_setting_value == 'false' || $bookingpress_setting_value == 'true' ) {
                    $bookingpress_setting_value = ( $bookingpress_setting_value == 'false' ) ? false : true;
                }                
                if (isset($bookingpress_my_booking_field_settings[ $bookingpress_setting_name ]) ) {
                    $bookingpress_my_booking_field_settings[ $bookingpress_setting_name ] = $bookingpress_setting_value;
                }
            }
            $bookingpress_return_data = array(
            'booking_form_settings' => $bookingpress_my_booking_field_settings,
            );

            $response['variant']  = 'success';
            $response['title']    = esc_html__('Success', 'bookingpress-appointment-booking');
            $response['msg']      = esc_html__('Field Settings Data Retrieved Successfully', 'bookingpress-appointment-booking');
            $response['formdata'] = $bookingpress_return_data;

            echo wp_json_encode($response);
            exit();
        }

        function bookingpress_save_form_settings_func()
        {
            global $wpdb, $BookingPress, $tbl_bookingpress_customize_settings;
            $response              = array();
            $wpnonce               = isset($_REQUEST['_wpnonce']) ? sanitize_text_field($_REQUEST['_wpnonce']) : '';
            $bpa_verify_nonce_flag = wp_verify_nonce($wpnonce, 'bpa_wp_nonce');
            if (! $bpa_verify_nonce_flag ) {
                $response['field_settings'] = '';
                $response['variant']        = 'error';
                $response['title']          = esc_html__('Error', 'bookingpress-appointment-booking');
                $response['msg']            = esc_html__('Sorry, Your request can not process due to security reason.', 'bookingpress-appointment-booking');
                echo wp_json_encode($response);
                exit;
            }

            $response['variant'] = 'error';
            $response['title']   = esc_html__('Error', 'bookingpress-appointment-booking');
            $response['msg']     = esc_html__('Something went wrong...', 'bookingpress-appointment-booking');
         // phpcs:disable WordPress.Security.ValidatedSanitizedInput.InputNotSanitized -- Reason:$_POST variables are contains mixed array and sanitized properly using appointment_sanatize_field function
            $tab_container_data              = ! empty($_POST['tab_container_data']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['tab_container_data']) : array();
            $category_container_data         = ! empty($_POST['category_container_data']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['category_container_data']) : array();
            $service_container_data          = ! empty($_POST['service_container_data']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['service_container_data']) : array();
            $timeslot_container_data         = ! empty($_POST['timeslot_container_data']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['timeslot_container_data']) : array();
            $bookingpress_colorpicker_values = ! empty($_POST['colorpicker_values']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['colorpicker_values']) : array();
            $bookingpress_font_values        = ! empty($_POST['font_values']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['font_values']) : array();
            $booking_form_settings           = ! empty($_POST['booking_form_settings']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['booking_form_settings']) : array();
            $summary_container_data          = ! empty($_POST['summary_container_data']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['summary_container_data']) : array();

            $front_lable_edit_data = ! empty($_POST['front_lable_edit_data']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['front_lable_edit_data']) : array();

            $booking_form_settings = apply_filters('bookingpress_before_save_customize_booking_form',$booking_form_settings);
            
         // phpcs:enable
            $bookingpress_customize_settings_data = array_merge($tab_container_data, $category_container_data, $service_container_data, $timeslot_container_data, $bookingpress_colorpicker_values, $bookingpress_font_values, $booking_form_settings, $summary_container_data, $front_lable_edit_data);
            if (! empty($bookingpress_customize_settings_data) ) {
                foreach ( $bookingpress_customize_settings_data as $bookingpress_setting_key => $bookingpress_setting_val ) {
                    $bookingpress_db_fields = array(
                    'bookingpress_setting_name'  => $bookingpress_setting_key,
                    'bookingpress_setting_value' => $bookingpress_setting_val,
                    'bookingpress_setting_type'  => 'booking_form',
                    );

                    $is_setting_exists = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(bookingpress_setting_id) as total FROM {$tbl_bookingpress_customize_settings} WHERE bookingpress_setting_name = %s AND bookingpress_setting_type = 'booking_form'", $bookingpress_setting_key) ); // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared -- Reason: $tbl_bookingpress_customize_settings is table name defined globally. False Positive alarm
                    if ($is_setting_exists > 0 ) {
                        $wpdb->update(
                            $tbl_bookingpress_customize_settings,
                            $bookingpress_db_fields,
                            array(
                            'bookingpress_setting_name' => $bookingpress_setting_key,
                            'bookingpress_setting_type' => 'booking_form',
                            )
                        );
                    } else {
                        $wpdb->insert($tbl_bookingpress_customize_settings, $bookingpress_db_fields);
                    }
                }
                $my_booking_form = array();
                $booking_form = array(
                    'background_color'         => $bookingpress_colorpicker_values['background_color'],
                    'footer_background_color'  => $bookingpress_colorpicker_values['footer_background_color'],
                    'primary_color'            => $bookingpress_colorpicker_values['primary_color'],
                    'primary_background_color' => $bookingpress_colorpicker_values['primary_background_color'],  
                    'label_title_color'        => $bookingpress_colorpicker_values['label_title_color'],
                    'title_font_family'        => $bookingpress_font_values['title_font_family'],
                    'content_color'            => $bookingpress_colorpicker_values['content_color'],
                    'sub_title_color'          => $bookingpress_colorpicker_values['sub_title_color'],
                    'price_button_text_color'  => $bookingpress_colorpicker_values['price_button_text_color'],
                    'custom_css'               => $bookingpress_colorpicker_values['custom_css'],      
                );
                 $bookingpress_action[] = 'bookingpress_save_booking_form_settings';
                $bookingpress_custom_data_arr = array(                    
                    'my_booking_form' => $my_booking_form, 
                    'booking_form' => $booking_form, 
                    'action' => $bookingpress_action,
                );
  
                $BookingPress->bookingpress_generate_customize_css_func($bookingpress_custom_data_arr);

                $response['variant'] = 'success';
                $response['title']   = esc_html__('Success', 'bookingpress-appointment-booking');
                $response['msg']     = esc_html__('Customize settings updated successfully.', 'bookingpress-appointment-booking');
            }

            echo wp_json_encode($response);
            exit();
        }

        function bookingpress_update_field_pos_func()
        {
            global $wpdb, $BookingPress, $tbl_bookingpress_form_fields;
            $response              = array();
            $wpnonce               = isset($_REQUEST['_wpnonce']) ? sanitize_text_field($_REQUEST['_wpnonce']) : '';
            $bpa_verify_nonce_flag = wp_verify_nonce($wpnonce, 'bpa_wp_nonce');
            if (! $bpa_verify_nonce_flag ) {
                $response['field_settings'] = '';
                $response['variant']        = 'error';
                $response['title']          = esc_html__('Error', 'bookingpress-appointment-booking');
                $response['msg']            = esc_html__('Sorry, Your request can not process due to security reason.', 'bookingpress-appointment-booking');
                echo wp_json_encode($response);
                exit;
            }

            $response['variant'] = 'error';
            $response['title']   = esc_html__('Error', 'bookingpress-appointment-booking');
            $response['msg']     = esc_html__('Something went wrong...', 'bookingpress-appointment-booking');

            $bookingpress_old_index = isset($_POST['old_index']) ? ( intval($_POST['old_index']) + 1 ) : 0;
            $bookingpress_new_index = isset($_POST['new_index']) ? ( intval($_POST['new_index']) + 1 ) : 0;
            $bookingpress_update_id = ! empty($_POST['update_id']) ? intval($_POST['update_id']) : 0;

            if (isset($_POST['old_index']) && isset($_POST['new_index']) ) {
                if ($bookingpress_new_index > $bookingpress_old_index ) {
                    $condition = 'BETWEEN ' . $bookingpress_old_index . ' AND ' . $bookingpress_new_index;
                    $fields    = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM ' . $tbl_bookingpress_form_fields . ' WHERE bookingpress_field_position BETWEEN %d AND %d order by bookingpress_field_position ASC', $bookingperss_old_index, $bookingpress_new_index ), ARRAY_A); // phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared -- Reason: $tbl_bookingpress_form_fields is table name defined globally. False Positive alarm
                    foreach ( $fields as $field ) {
                        $position = $field['bookingpress_field_position'] - 1;
                        $position = ( $field['bookingpress_field_position'] == $bookingpress_old_index ) ? $bookingpress_new_index : $position;
                        $args     = array(
                         'bookingpress_field_position' => $position,
                        );
                        $wpdb->update($tbl_bookingpress_form_fields, $args, array( 'bookingpress_form_field_id' => $field['bookingpress_form_field_id'] ));
                    }
                } else {
                    $fields = $wpdb->get_results( $wpdb->prepare( 'SELECT * FROM ' . $tbl_bookingpress_form_fields . ' WHERE bookingpress_field_position BETWEEN %d AND %d order by bookingpress_field_position ASC', $bookingpress_new_index, $bookingpress_old_index ), ARRAY_A); // phpcs:ignore WordPress.DB.PreparedSQL.NotPrepared -- Reason: $tbl_bookingpress_form_fields is table name defined globally. False Positive alarm
                    foreach ( $fields as $field ) {
                        $position = $field['bookingpress_field_position'] + 1;
                        $position = ( $field['bookingpress_field_position'] == $bookingpress_old_index ) ? $bookingpress_new_index : $position;
                        $args     = array(
                        'bookingpress_field_position' => $position,
                        );
                        $wpdb->update($tbl_bookingpress_form_fields, $args, array( 'bookingpress_form_field_id' => $field['bookingpress_form_field_id'] ));
                    }
                }
                $response['variant'] = 'success';
                $response['title']   = esc_html__('Success', 'bookingpress-appointment-booking');
                $response['msg']     = esc_html__('Field position has been changed successfully.', 'bookingpress-appointment-booking');
            }

            echo wp_json_encode($response);
            exit();
        }

        function bookingpress_load_field_settings_func()
        {
            global $wpdb, $BookingPress, $tbl_bookingpress_form_fields;
            $response              = array();
            $wpnonce               = isset($_REQUEST['_wpnonce']) ? sanitize_text_field($_REQUEST['_wpnonce']) : '';
            $bpa_verify_nonce_flag = wp_verify_nonce($wpnonce, 'bpa_wp_nonce');
            if (! $bpa_verify_nonce_flag ) {
                $response['field_settings'] = '';
                $response['variant']        = 'error';
                $response['title']          = esc_html__('Error', 'bookingpress-appointment-booking');
                $response['msg']            = esc_html__('Sorry, Your request can not process due to security reason.', 'bookingpress-appointment-booking');
                echo wp_json_encode($response);
                exit;
            }

            $bookingpress_field_settings_data        = $wpdb->get_results("SELECT * FROM {$tbl_bookingpress_form_fields} ORDER BY bookingpress_field_position ASC", ARRAY_A); // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared -- Reason: $tbl_bookingpress_form_fields is table name defined globally. False Positive alarm
            $bookingpress_field_settings_data        = apply_filters('bookingpress_modify_field_data_before_prepare', $bookingpress_field_settings_data);
            $bookingpress_field_settings_return_data = array();
            foreach ( $bookingpress_field_settings_data as $bookingpress_field_setting_key => $bookingpress_field_setting_val ) {
                $bookingpress_field_type = '';
                if ($bookingpress_field_setting_val['bookingpress_form_field_name'] == 'fullname' ) {
                    $bookingpress_field_type = 'Text';
                } elseif ($bookingpress_field_setting_val['bookingpress_form_field_name'] == 'firstname' ) {
                    $bookingpress_field_type = 'Text';
                } elseif ($bookingpress_field_setting_val['bookingpress_form_field_name'] == 'lastname' ) {
                    $bookingpress_field_type = 'Text';
                } elseif ($bookingpress_field_setting_val['bookingpress_form_field_name'] == 'email_address' ) {
                    $bookingpress_field_type = 'Email';
                } elseif ($bookingpress_field_setting_val['bookingpress_form_field_name'] == 'phone_number' ) {
                    $bookingpress_field_type = 'Dropdown';
                } elseif ($bookingpress_field_setting_val['bookingpress_form_field_name'] == 'note' ) {
                    $bookingpress_field_type = 'Textarea';
                } else {
                    $bookingpress_field_type = $bookingpress_field_setting_val['bookingpress_field_type'];
                }

                $bookingpress_draggable_field_setting_fields_tmp                   = array();
                $bookingpress_draggable_field_setting_fields_tmp['id']             = intval($bookingpress_field_setting_val['bookingpress_form_field_id']);
                $bookingpress_draggable_field_setting_fields_tmp['field_name']     = $bookingpress_field_setting_val['bookingpress_form_field_name'];
                $bookingpress_draggable_field_setting_fields_tmp['field_type']     = $bookingpress_field_type;
                $bookingpress_draggable_field_setting_fields_tmp['is_edit']        = false;
                $bookingpress_draggable_field_setting_fields_tmp['is_required']    = ( $bookingpress_field_setting_val['bookingpress_field_required'] == 0 ) ? false : true;
                $bookingpress_draggable_field_setting_fields_tmp['label']          = stripslashes_deep($bookingpress_field_setting_val['bookingpress_field_label']);
                $bookingpress_draggable_field_setting_fields_tmp['placeholder']    = stripslashes_deep($bookingpress_field_setting_val['bookingpress_field_placeholder']);
                $bookingpress_draggable_field_setting_fields_tmp['error_message']  = stripslashes_deep($bookingpress_field_setting_val['bookingpress_field_error_message']);
                $bookingpress_draggable_field_setting_fields_tmp['is_hide']        = ( $bookingpress_field_setting_val['bookingpress_field_is_hide'] == 0 ) ? false : true;
                $bookingpress_draggable_field_setting_fields_tmp['field_position'] = floatval($bookingpress_field_setting_val['bookingpress_field_position']);

                $bookingpress_draggable_field_setting_fields_tmp = apply_filters('bookingpress_modify_field_data_before_load', $bookingpress_draggable_field_setting_fields_tmp, $bookingpress_field_setting_val);

                array_push($bookingpress_field_settings_return_data, $bookingpress_draggable_field_setting_fields_tmp);
            }

            $response['variant']        = 'success';
            $response['title']          = esc_html__('Success', 'bookingpress-appointment-booking');
            $response['msg']            = esc_html__('Field Settings Data Retrieved Successfully', 'bookingpress-appointment-booking');
            $response['field_settings'] = $bookingpress_field_settings_return_data;

            echo wp_json_encode($response);
            exit();
        }

        function bookingpress_save_field_settings_data_func()
        {
            global $wpdb, $BookingPress, $tbl_bookingpress_form_fields;
            $response              = array();
            $wpnonce               = isset($_REQUEST['_wpnonce']) ? sanitize_text_field($_REQUEST['_wpnonce']) : '';
            $bpa_verify_nonce_flag = wp_verify_nonce($wpnonce, 'bpa_wp_nonce');
            if (! $bpa_verify_nonce_flag ) {
                $response['variant'] = 'error';
                $response['title']   = esc_html__('Error', 'bookingpress-appointment-booking');
                $response['msg']     = esc_html__('Sorry, Your request can not process due to security reason.', 'bookingpress-appointment-booking');
                echo wp_json_encode($response);
                exit;
            }

            $response['variant'] = 'error';
            $response['title']   = esc_html__('Error', 'bookingpress-appointment-booking');
            $response['msg']     = esc_html__('Something went wrong...', 'bookingpress-appointment-booking');
         // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized -- Reason:$_POST['field_settings'] cotains mixed array and will be sanitized properly using 'appointment_sanatize_field' function
            $bookingpress_field_settings_data = ! empty($_POST['field_settings']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['field_settings']) : array();
            if (! empty($bookingpress_field_settings_data) ) {
                foreach ( $bookingpress_field_settings_data as $bookingpress_field_setting_key => $bookingpress_field_setting_val ) {
                    $bookingpress_field_name = $bookingpress_field_setting_val['field_name'];

                    $bookingpress_db_fields = array(
                    'bookingpress_form_field_name'     => $bookingpress_field_name,
                    'bookingpress_field_required'      => ( $bookingpress_field_setting_val['is_required'] == 'false' ) ? 0 : 1,
                    'bookingpress_field_label'         => $bookingpress_field_setting_val['label'],
                    'bookingpress_field_placeholder'   => $bookingpress_field_setting_val['placeholder'],
                    'bookingpress_field_error_message' => $bookingpress_field_setting_val['error_message'],
                    'bookingpress_field_is_hide'       => ( $bookingpress_field_setting_val['is_hide'] == 'false' ) ? 0 : 1,
                    'bookingpress_field_position'      => $bookingpress_field_setting_val['field_position'],
                    );

                    $bpa_existing_field_id = $bookingpress_field_setting_val['id'];

                    $bookingpress_db_fields = apply_filters('bookingpress_modify_form_field_data_before_save', $bookingpress_db_fields, $bookingpress_field_setting_val);

                    $field_exist = $wpdb->get_var($wpdb->prepare("SELECT COUNT(bookingpress_form_field_id) as total FROM {$tbl_bookingpress_form_fields} WHERE bookingpress_form_field_id = %d", $bpa_existing_field_id)); // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared -- Reason: $tbl_bookingpress_form_fields is table name defined globally. False Positive alarm
                    if ($field_exist > 0 ) {
                        $wpdb->update($tbl_bookingpress_form_fields, $bookingpress_db_fields, array( 'bookingpress_form_field_id' => $bpa_existing_field_id ));
                    } else {
                        $wpdb->insert($tbl_bookingpress_form_fields, $bookingpress_db_fields);
                        $bpa_existing_field_id = $wpdb->insert_id;
                    }

                    do_action('bookingpress_insert_inner_fields', $bookingpress_db_fields, $bookingpress_field_setting_key, $bpa_existing_field_id);
                }

                do_action('bookingpress_delete_removed_fields', $bookingpress_field_settings_data);

                $response['variant'] = 'success';
                $response['title']   = esc_html__('Success', 'bookingpress-appointment-booking');
                $response['msg']     = esc_html__('Field Settings Data Saved Successfully', 'bookingpress-appointment-booking');
            }

            echo wp_json_encode($response);
            exit();
        }

        function bookingpress_save_my_booking_settings_func()
        {
            global $wpdb, $BookingPress, $tbl_bookingpress_customize_settings;
            $response              = array();
            $wpnonce               = isset($_REQUEST['_wpnonce']) ? sanitize_text_field($_REQUEST['_wpnonce']) : '';
            $bpa_verify_nonce_flag = wp_verify_nonce($wpnonce, 'bpa_wp_nonce');
            if (! $bpa_verify_nonce_flag ) {
                $response['field_settings'] = '';
                $response['variant']        = 'error';
                $response['title']          = esc_html__('Error', 'bookingpress-appointment-booking');
                $response['msg']            = esc_html__('Sorry, Your request can not process due to security reason.', 'bookingpress-appointment-booking');
                echo wp_json_encode($response);
                exit;
            }

            $response['variant'] = 'error';
            $response['title']   = esc_html__('Error', 'bookingpress-appointment-booking');
            $response['msg']     = esc_html__('Something went wrong...', 'bookingpress-appointment-booking');
         // phpcs:disable WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
            $bookingpress_colorpicker_data = ! empty($_POST['my_booking_selected_colorpicker_values']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['my_booking_selected_colorpicker_values']) : array();
            $bookingpress_font_values_data = ! empty($_POST['my_booking_selected_font_values']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['my_booking_selected_font_values']) : array();
            $bookingpress_settings_data    = ! empty($_POST['my_booking_field_settings']) ? array_map(array( $BookingPress, 'appointment_sanatize_field' ), $_POST['my_booking_field_settings']) : array();
         // phpcs:enable
            $bookingpress_customize_settings_data = array_merge($bookingpress_colorpicker_data, $bookingpress_font_values_data, $bookingpress_settings_data);
            if (! empty($bookingpress_customize_settings_data) ) {
                foreach ( $bookingpress_customize_settings_data as $bookingpress_setting_key => $bookingpress_setting_val ) {
                    $bookingpress_db_fields = array(
                    'bookingpress_setting_name'  => $bookingpress_setting_key,
                    'bookingpress_setting_value' => $bookingpress_setting_val,
                    'bookingpress_setting_type'  => 'booking_my_booking',
                    );

                    $is_setting_exists = $wpdb->get_var( $wpdb->prepare( "SELECT COUNT(bookingpress_setting_id) as total FROM {$tbl_bookingpress_customize_settings} WHERE bookingpress_setting_name = %s AND bookingpress_setting_type = 'booking_my_booking'", $bookingpress_setting_key )); // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared -- Reason: $tbl_bookingpress_customize_settings is table name defined globally. False Positive alarm
                    if ($is_setting_exists > 0 ) {
                        $wpdb->update(
                            $tbl_bookingpress_customize_settings,
                            $bookingpress_db_fields,
                            array(
                            'bookingpress_setting_name' => $bookingpress_setting_key,
                            'bookingpress_setting_type' => 'booking_my_booking',
                            )
                        );
                    } else {
                        $wpdb->insert($tbl_bookingpress_customize_settings, $bookingpress_db_fields);
                    }
                }
                $my_booking_form = array(         
                    'background_color'     => $bookingpress_colorpicker_data['background_color'],
                    'row_background_color' => $bookingpress_colorpicker_data['footer_background_color'],
                    'primary_color'        => $bookingpress_colorpicker_data['primary_color'],
                    'label_title_color'    => $bookingpress_colorpicker_data['label_title_color'],
                    'sub_title_color'      => $bookingpress_colorpicker_data['sub_title_color'],
                    'content_color'        => $bookingpress_colorpicker_data['content_color'],
                    'title_font_family'    => $bookingpress_font_values_data['title_font_family'],
                    'custom_css'           => $bookingpress_colorpicker_data['custom_css'],
                    'price_button_text_color' => $bookingpress_colorpicker_data['price_button_text_color'],
                );
                $bookingpress_action[] = 'bookingpress_save_my_booking_settings';

                $booking_form = array();
                $bookingpress_custom_data_arr = array(                    
                    'my_booking_form' => $my_booking_form, 
                    'booking_form' => $booking_form, 
                    'action' => $bookingpress_action,
                );

               $BookingPress->bookingpress_generate_customize_css_func($bookingpress_custom_data_arr);

                $response['variant'] = 'success';
                $response['title']   = esc_html__('Success', 'bookingpress-appointment-booking');
                $response['msg']     = esc_html__('Customize settings updated successfully.', 'bookingpress-appointment-booking');
            }

            echo wp_json_encode($response);
            exit();
        }

        function bookingpress_customize_helper_vars_func()
        {
            global $bookingpress_global_options;
            $bookingpress_options     = $bookingpress_global_options->bookingpress_global_options();
            $bookingpress_locale_lang = $bookingpress_options['locale'];
            ?>
            var lang = ELEMENT.lang.<?php echo esc_html($bookingpress_locale_lang); ?>;
            ELEMENT.locale(lang)
            <?php
        }

        function bookingpress_dynamic_components_func()
        {
            ?>
                'vue-cal': vuecal
            <?php
        }

        function bookingpress_dynamic_vue_methods_func()
        {
            global $bookingpress_notification_duration;
            ?>
                bpa_select_category(selected_category){
                    const vm = this
                    vm.bookingpress_shortcode_form.selected_category = selected_category
                },
                bpa_select_service(selected_service){
                    const vm = this
                    vm.bookingpress_shortcode_form.selected_service = selected_service
                },
                bpa_select_time(selected_time){
                    const vm = this
                    vm.bookingpress_shortcode_form.selected_time = selected_time
                },
                bpa_select_primary_color(selected_color){
                    var opacity_color = Math.round(Math.min(Math.max(0.12 || 1, 0), 1) * 255);
                    var primary_background_color = selected_color+(opacity_color.toString(16).toUpperCase())
                    this.selected_colorpicker_values.primary_background_color = primary_background_color
                },
                bpa_reset_bookingform(){
                    const vm = this
                    vm.selected_colorpicker_values.background_color = '#FFF'
                    vm.selected_colorpicker_values.footer_background_color = '#f4f7fb'
                    vm.selected_colorpicker_values.primary_color = '#12D488'
                    vm.selected_colorpicker_values.primary_background_color = '#e2faf1'
                    vm.selected_colorpicker_values.label_title_color = '#202C45'
                    vm.selected_colorpicker_values.content_color = '#727E95'
                    vm.selected_colorpicker_values.price_button_text_color = '#fff'                    
                    vm.selected_font_values.title_font_family = 'Poppins'
                    vm.selected_colorpicker_values.sub_title_color = '#535D71'
                },      
                bpa_save_booking_form_settings_data(){
                    const vm2 = this
                    var postData = []
                    postData.action = 'bookingpress_save_form_settings'
                    postData.tab_container_data = vm2.tab_container_data
                    postData.category_container_data = vm2.category_container_data
                    postData.service_container_data = vm2.service_container_data
                    postData.timeslot_container_data = vm2.timeslot_container_data
                    postData.colorpicker_values = vm2.selected_colorpicker_values
                    postData.font_values = vm2.selected_font_values
                    postData.front_lable_edit_data = vm2.front_lable_edit_data
                    postData.booking_form_settings = vm2.booking_form_settings
                    postData.summary_container_data = vm2.summary_container_data
                    <?php do_action('bookingpress_before_save_customize_form_settings'); ?>
                    postData._wpnonce = '<?php echo esc_html(wp_create_nonce('bpa_wp_nonce')); ?>'
                    axios.post( appoint_ajax_obj.ajax_url, Qs.stringify( postData ) )
                    .then( function (response) {
                        if(response.data.variant == 'error'){
                            vm2.$notify({
                                title: response.data.title,
                                message: response.data.msg,
                                type: response.data.variant,
                                customClass: response.data.variant+'_notification',
                                duration:<?php echo intval($bookingpress_notification_duration); ?>,
                            });    
                        }
                    }.bind(this) )
                    .catch( function (error) {                    
                        vm2.$notify({
                            title: '<?php esc_html_e('Error', 'bookingpress-appointment-booking'); ?>',
                            message: '<?php esc_html_e('Something Went wrong...', 'bookingpress-appointment-booking'); ?>',
                            type: 'error',
                            customClass: 'error_notification',
                            duration:<?php echo intval($bookingpress_notification_duration); ?>,
                        });
                    });
                },
                bpa_save_field_settings_data(){
                    const vm2 = this
                    var postData = [];
            <?php do_action('bookingpress_before_save_field_settings_method'); ?>
                    postData.action = 'bookingpress_save_field_settings'
                    postData.field_settings = vm2.field_settings_fields
                    postData._wpnonce = '<?php echo esc_html(wp_create_nonce('bpa_wp_nonce')); ?>'
                    axios.post( appoint_ajax_obj.ajax_url, Qs.stringify( postData ) )
                    .then( function (response) {
                        if(response.data.variant == 'error'){
                            vm2.$notify({
                                title: response.data.title,
                                message: response.data.msg,
                                type: response.data.variant,
                                customClass: response.data.variant+'_notification',                                
                                duration:<?php echo intval($bookingpress_notification_duration); ?>,
                            });    
                        }
            <?php do_action('bookingpress_after_save_field_settings_method'); ?>
                    }.bind(this) )
                    .catch( function (error) {                    
                        vm2.$notify({
                            title: '<?php esc_html_e('Error', 'bookingpress-appointment-booking'); ?>',
                            message: '<?php esc_html_e('Something Went wrong...', 'bookingpress-appointment-booking'); ?>',
                            type: 'error',
                            customClass: 'error_notification',
                            duration:<?php echo intval($bookingpress_notification_duration); ?>,
                        });
                    });
                },
                bpa_save_field_my_booking_data() {
                    const vm2 = this
                    var postData = []
                    postData.action = 'bookingpress_save_my_booking_settings'
                    postData.my_booking_field_settings = vm2.my_booking_field_settings
                    postData.my_booking_selected_font_values = vm2.selected_font_values
                    postData.my_booking_selected_colorpicker_values = vm2.selected_colorpicker_values
                    postData._wpnonce = '<?php echo esc_html(wp_create_nonce('bpa_wp_nonce')); ?>'
                    axios.post( appoint_ajax_obj.ajax_url, Qs.stringify( postData ) )
                    .then( function (response) {
                        if(response.data.variant == 'error'){
                            vm2.$notify({
                                title: response.data.title,
                                message: response.data.msg,
                                type: response.data.variant,
                                customClass: response.data.variant+'_notification',
                                duration:<?php echo intval($bookingpress_notification_duration); ?>,
                            });    
                        }
                    }.bind(this) )
                    .catch( function (error) {                    
                        vm2.$notify({
                            title: '<?php esc_html_e('Error', 'bookingpress-appointment-booking'); ?>',
                            message: '<?php esc_html_e('Something Went wrong...', 'bookingpress-appointment-booking'); ?>',
                            type: 'error',
                            customClass: 'error_notification',
                            duration:<?php echo intval($bookingpress_notification_duration); ?>,
                        });
                    });
                },
                bpa_save_customize_settings(action){
                    const vm = this
                    vm.is_display_save_loader = '1'
                    vm.is_disabled = 1
                    if(action == 'form_fields') {
                        vm.bpa_save_field_settings_data()
                    } else {                        
                        vm.bpa_save_booking_form_settings_data()                    
                        vm.bpa_save_field_my_booking_data()                
                    }

                    setTimeout(function(){
                        vm.is_display_save_loader = '0'
                        vm.is_disabled = 0
                        vm.$notify({
                            title: '<?php esc_html_e('Success', 'bookingpress-appointment-booking'); ?>',
                            message: '<?php esc_html_e('Customization settings saved successfully', 'bookingpress-appointment-booking'); ?>',
                            type: 'success',
                            customClass: 'success_notification',
                            duration:<?php echo intval($bookingpress_notification_duration); ?>,
                        });
                    }, 3000);
                },
                bookingpress_load_booking_form_data(){
                    const vm2 = this
                    var postData = []
                    postData.action = 'bookingpress_load_bookingform_data'
                    postData._wpnonce = '<?php echo esc_html(wp_create_nonce('bpa_wp_nonce')); ?>'
                    axios.post( appoint_ajax_obj.ajax_url, Qs.stringify( postData ) )
                    .then( function (response) {
                        if(response.data.variant == 'error'){
                            vm2.$notify({
                                title: response.data.title,
                                message: response.data.msg,
                                type: response.data.variant,
                                customClass: response.data.variant+'_notification',
                                duration:<?php echo intval($bookingpress_notification_duration); ?>,
                            });
                        }else{
                            vm2.tab_container_data = response.data.formdata.tab_container_data
                            vm2.category_container_data = response.data.formdata.category_container_data
                            vm2.service_container_data = response.data.formdata.service_container_data
                            vm2.timeslot_container_data = response.data.formdata.timeslot_container_data
                            vm2.selected_colorpicker_values = response.data.formdata.colorpicker_values
                            vm2.selected_font_values.title_font_family = response.data.formdata.font_values.title_font_family
                            vm2.booking_form_settings = response.data.formdata.booking_form_settings
                            vm2.summary_container_data = response.data.formdata.summary_container_data
                            vm2.front_lable_edit_data = response.data.formdata.front_lable_edit_data
                        }
                    }.bind(this) )
                    .catch( function (error) {                    
                        vm2.$notify({
                            title: '<?php esc_html_e('Error', 'bookingpress-appointment-booking'); ?>',
                            message: '<?php esc_html_e('Something Went wrong...', 'bookingpress-appointment-booking'); ?>',
                            type: 'error',
                            customClass: 'error_notification',
                            duration:<?php echo intval($bookingpress_notification_duration); ?>,
                        });
                    });
                },
                bookingpress_load_field_settings_data(){
                    const vm2 = this
                    var postData = []
                    postData.action = 'bookingpress_load_field_settings'
                    postData._wpnonce = '<?php echo esc_html(wp_create_nonce('bpa_wp_nonce')); ?>'
                    axios.post( appoint_ajax_obj.ajax_url, Qs.stringify( postData ) )
                    .then( function (response) {
                        if(response.data.variant == 'error'){
                            vm2.$notify({
                                title: response.data.title,
                                message: response.data.msg,
                                type: response.data.variant,
                                customClass: response.data.variant+'_notification',
                                duration:<?php echo intval($bookingpress_notification_duration); ?>,
                            });
                        }else{
                            vm2.field_settings_fields = response.data.field_settings;
            <?php do_action('bookingpress_after_load_field_settings'); ?>
                        }
                    }.bind(this) )
                    .catch( function (error) {                    
                        vm2.$notify({
                            title: '<?php esc_html_e('Error', 'bookingpress-appointment-booking'); ?>',
                            message: '<?php esc_html_e('Something Went wrong...', 'bookingpress-appointment-booking'); ?>',
                            type: 'error',
                            customClass: 'error_notification',
                            duration:<?php echo intval($bookingpress_notification_duration); ?>,
                        });
                    });
                },
                bookingpress_load_my_booking_data(){
                    const vm2 = this
                    var postData = []
                    postData.action = 'bookingpress_load_my_booking_data'
                    postData._wpnonce = '<?php echo esc_html(wp_create_nonce('bpa_wp_nonce')); ?>'
                    axios.post( appoint_ajax_obj.ajax_url, Qs.stringify( postData ) )
                    .then( function (response) {
                        if(response.data.variant == 'error'){
                            vm2.$notify({
                                title: response.data.title,
                                message: response.data.msg,
                                type: response.data.variant,
                                customClass: response.data.variant+'_notification',
                                duration:<?php echo intval($bookingpress_notification_duration); ?>,
                            });
                        }else{
                            vm2.my_booking_field_settings = response.data.formdata.booking_form_settings
                        }
                    }.bind(this) )
                    .catch( function (error) {                    
                        vm2.$notify({
                            title: '<?php esc_html_e('Error', 'bookingpress-appointment-booking'); ?>',
                            message: '<?php esc_html_e('Something Went wrong...', 'bookingpress-appointment-booking'); ?>',
                            type: 'error',
                            customClass: 'error_notification',
                            duration:<?php echo intval($bookingpress_notification_duration); ?>,
                        });
                    });
                },
                updateFieldPos(e){
                    const vm2 = this
                    var field_pos_update_id = e.draggedContext.element.id
                    var old_index = e.draggedContext.index
                    var new_index = e.draggedContext.futureIndex
                    var postData = []
                    postData.action = 'bookingpress_update_field_position'
                    postData.old_index = old_index
                    postData.new_index = new_index
                    postData.update_id = field_pos_update_id
                    postData._wpnonce = '<?php echo esc_html(wp_create_nonce('bpa_wp_nonce')); ?>'
                    axios.post( appoint_ajax_obj.ajax_url, Qs.stringify( postData ) )
                    .then( function (response) {
                        if(response.data.variant == 'error'){
                            vm2.$notify({
                                title: response.data.title,
                                message: response.data.msg,
                                type: response.data.variant,
                                customClass: response.data.variant+'_notification',
                                duration:<?php echo intval($bookingpress_notification_duration); ?>,
                            });
                        }
                        vm2.bookingpress_load_field_settings_data()
                    }.bind(this) )
                    .catch( function (error) {                    
                        vm2.$notify({
                            title: '<?php esc_html_e('Error', 'bookingpress-appointment-booking'); ?>',
                            message: '<?php esc_html_e('Something Went wrong...', 'bookingpress-appointment-booking'); ?>',
                            type: 'error',
                            customClass: 'error_notification',
                            duration:<?php echo intval($bookingpress_notification_duration); ?>,
                        });
                    });    
                },
                closeFieldSettings(field_name){
                    //this.field_settings_fields[field_name].is_edit = 0
                    var field_settings = this.field_settings_fields
                    field_settings.forEach(function(item, index, arr){
                        item.is_edit = 0
                    });
                },          
                open_custom_css_modal(){
                    const vm = this;
                    vm.css_action = '';
                    vm.add_custom_css_modal = true;
                    vm.bookigpress_form_custom_css = vm.selected_colorpicker_values.custom_css;                                        
                },
                close_custom_css_modal() {
                    const vm = this;
                    vm.add_custom_css_modal = false;
                    vm.bookigpress_form_custom_css ='';                    
                },
                bookingpress_save_custom_css() {
                    const vm = this
                    vm.selected_colorpicker_values.custom_css = vm.bookigpress_form_custom_css;                    
                    vm.close_custom_css_modal();
                },
                bookingpress_change_tab(tabname) {
                    const vm = this;
                    vm.bookingpress_tab_change_loader = '1';
                    setTimeout(function(){
                        vm.bookingpress_tab_change_loader = '0';
                        vm.activeTabName = tabname;
                    },1000);
                },         
            <?php
        }

        function bookingpress_dynamic_onload_methods_func()
        {   
            $request_action = ( ! empty($_REQUEST['action']) ) ? sanitize_text_field($_REQUEST['action']) : 'forms'; //// phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized --Reason - $_REQUEST['action'] sanitized properly
            if($request_action == 'form_fields') {
                ?>
                const vm = this
                vm.bookingpress_load_field_settings_data()
                <?php
            } else {                    
            ?>  
                const vm = this
                vm.bookingpress_load_booking_form_data()
                vm.bookingpress_load_my_booking_data()
            <?php
            }
        }

        function bookingpress_dynamic_computed_methods_func()
        {
            ?>
            <?php
        }

        function bookingpress_load_customize_dynamic_view_func()
        {
                
            $bookingpress_load_file_name = BOOKINGPRESS_VIEWS_DIR . '/customize/manage_form_customize.php';
            if(!empty($_REQUEST['action']) && !empty($_REQUEST['action'] == 'form_fields')) {
                $bookingpress_load_file_name = BOOKINGPRESS_VIEWS_DIR . '/customize/manage_form_field_customize.php';
            }
            $bookingpress_load_file_name = apply_filters('bookingpress_modify_customize_view_file_path', $bookingpress_load_file_name);
            include $bookingpress_load_file_name;
        }

        function bookingpress_dynamic_data_fields_func()
        {
            global $bookingpress_customize_vue_data_fields, $BookingPress, $bookingpress_global_options, $tbl_bookingpress_form_fields, $tbl_bookingpress_customize_settings,$wpdb;
            $default_daysoff_details = $BookingPress->bookingpress_get_default_dayoff_dates();
            $disabled_date           = implode(',', $default_daysoff_details);
            $bookingpress_customize_vue_data_fields['days_off_disabled_dates'] = $disabled_date;

            // Load fonts options
            $bookingpress_inherit_fonts_list = array(
                'Inherit Fonts',
            );
            $bookingpress_default_fonts_list = $bookingpress_global_options->bookingpress_get_default_fonts();
            $bookingpress_google_fonts_list  = $bookingpress_global_options->bookingpress_get_google_fonts();            
            $bookingpress_options      = $bookingpress_global_options->bookingpress_global_options();
            $bookingpress_country_list = json_decode($bookingpress_options['country_lists']);
            $bookingpress_all_pages = get_pages();
            $bookingpress_all_pages = json_decode(json_encode($bookingpress_all_pages), true);   
            $bookingpress_fonts_list         = array(
                array(
                    'label'   => __('Inherit Fonts', 'bookingpress-appointment-booking'),
                    'options' => $bookingpress_inherit_fonts_list,
                ),
                array(
                    'label'   => __('Default Fonts', 'bookingpress-appointment-booking'),
                    'options' => $bookingpress_default_fonts_list,
                ),
                array(
                    'label'   => __('Google Fonts', 'bookingpress-appointment-booking'),
                    'options' => $bookingpress_google_fonts_list,
                ),
            );
            $bookingpress_customize_vue_data_fields['bookingpress_shortcode_form']['phone_countries_details'] = $bookingpress_country_list;
            $bookingpress_customize_vue_data_fields['bookingpress_all_global_pages'] = $bookingpress_all_pages;

            $bookingpress_customize_vue_data_fields['fonts_list'] = $bookingpress_fonts_list;
              $bookingpress_phone_country_option                  = $BookingPress->bookingpress_get_settings('default_phone_country_code', 'general_setting');
            $bookingpress_customize_vue_data_fields['bookingpress_tel_input_props'] = array(
            'defaultCountry' => $bookingpress_phone_country_option,
            );                                       
            $bookingpress_customize_vue_data_fields = apply_filters('bookingpress_customize_add_dynamic_data_fields', $bookingpress_customize_vue_data_fields);
            echo wp_json_encode($bookingpress_customize_vue_data_fields);
        }

        function bookingpress_get_form_fields_func()
        {
            global $wpdb, $BookingPress, $tbl_bookingpress_form_fields;
            $bookingpress_form_fields_arr = array();
            $bookingpress_get_form_fields = $wpdb->get_results("SELECT * FROM {$tbl_bookingpress_form_fields}", ARRAY_A); // phpcs:ignore WordPress.DB.PreparedSQL.InterpolatedNotPrepared -- Reason: $tbl_bookingpress_form_fields is table name defined globally. False Positive alarm
            foreach ( $bookingpress_get_form_fields as $bookingpress_form_field_key => $bookingpress_form_field_val ) {
                $bookingpress_form_fields_arr[] = array(
                'label'      => $bookingpress_form_field_val['bookingpress_field_label'],
                'field_name' => $bookingpress_form_field_val['bookingpress_form_field_name'],
                );
            }

            $bookingpress_form_fields_arr = apply_filters('bookingpress_modify_form_field_data', $bookingpress_form_fields_arr);

            return $bookingpress_form_fields_arr;
        }
    }

    global $bookingpress_customize, $bookingpress_customize_vue_data_fields;
    $bookingpress_customize = new bookingpress_customize();

    
    $bookingpress_customize_vue_data_fields = array(
    'is_display_loader'                      => '0',
    'is_display_save_loader'                 => '0',
    'is_disabled'                            => 0,
    'dragging'                               => false,
    'activeTabName'                          => 'booking_form',
    'bpa_activeTabName'                      => 'booking_form',
    'bookingpress_tab_change_loader'         => '0',
    'formActiveTab'                          => '1',
    'appointment_date_range'                 => array( date('Y-m-d', strtotime('-3 Day')), date('Y-m-d', strtotime('+3 Day')) ),
    'tab_container_data'                     => array(    
        'service_title'           => __('Services', 'bookingpress-appointment-booking'),
        'datetime_title'          => __('Date & Time', 'bookingpress-appointment-booking'),
        'basic_details_title'     => __('Basic Details', 'bookingpress-appointment-booking'),
        'summary_title'           => __('Summary', 'bookingpress-appointment-booking'),
    ),
    'category_container_data'                => array(
        'category_title'         => __('Select Category', 'bookingpress-appointment-booking'),		
		'all_category_title'     => __( 'ALL', 'bookingpress-appointment-booking' ),
    ),
    'service_container_data'                 => array(    
        'service_heading_title' => __('Select Service', 'bookingpress-appointment-booking'),
        'default_image_url'     => BOOKINGPRESS_URL . '/images/placeholder-img.jpg',
    ),
    'timeslot_container_data'                => array(
        'timeslot_text'    => __('Time Slot', 'bookingpress-appointment-booking'),
    ),
    'summary_container_data'       => array(    
        'summary_content_text'  => __('Your appointment booking summary', 'bookingpress-appointment-booking'),    
        'payment_method_text'   => __('Select Payment Method', 'bookingpress-appointment-booking'),
    ),
    'front_lable_edit_data' =>  array(
        'paypal_text'         => __('PayPal', 'bookingpress-appointment-booking'),
        'locally_text'        => __('Pay Locally', 'bookingpress-appointment-booking'),
        'total_amount_text'   => __('Total Amount Payable', 'bookingpress-appointment-booking'),
        'service_text'        => __('Service', 'bookingpress-appointment-booking'),
        'customer_text'       => __('Customer', 'bookingpress-appointment-booking'),
        'date_time_text'      => __('Date &amp; Time', 'bookingpress-appointment-booking'),
    ),
    'bookingpress_shortcode_form'            => array(
        'selected_category'         => 'low_consultancy',
        'selected_service'          => 'chronic_disease_management_1',
        'selected_date'             => date('Y-m-d', current_time('timestamp')),
        'selected_time'             => '17:00',
        'customer_name'             => '',
        'customer_selected_country' => 'us',
        'cusomter_phone'            => '',
        'customer_email'            => '',
        'customer_note'             => '',
    ),
    'selected_colorpicker_values'            => array(
        'background_color'         => '#fff',
        'footer_background_color'  => '#f4f7fb',
        'primary_color'            => '#12D488',
        'primary_background_color' => '#e2faf1',
        'label_title_color'        => '#202C45',
        'sub_title_color'        =>   '#535D71',
        'content_color'            => '#727E95',
        'price_button_text_color'  => '#fff',
        'custom_css'               => '',    
    ),
    'selected_font_values'                   => array(
        'title_font_size'     => '18',
        'title_font_family'   => 'Poppins',
        'content_font_size'   => '14',
        'sub_title_font_size'   => '16',
    ),
    'booking_form_settings'                  => array(
        'hide_category_service_selection' => false,
        'hide_already_booked_slot'        => false,
        'display_service_description'     => false,
        'booking_form_tabs_position'      => 'left',
        'goback_button_text'              => __('Go Back', 'bookingpress-appointment-booking'),
        'next_button_text'                => __('Next', 'bookingpress-appointment-booking'),
        'book_appointment_btn_text'       => __('Book Appointment', 'bookingpress-appointment-booking'),
        'after_booking_redirection'       => '',
        'after_failed_payment_redirection' =>  '',
    ),
    'draggable_field_setting_fields'         => array(),
    'field_settings_fields'                  => array(
        'fullname'      => array(
            'field_name'     => 'fullname',
            'field_type'     => 'Text',
            'is_edit'        => 0,
            'is_required'    => 0,
            'label'          => __('Fullname', 'bookingpress-appointment-booking'),
            'placeholder'    => __('Enter your full name', 'bookingpress-appointment-booking'),
            'error_message'  => __('Please enter your full name', 'bookingpress-appointment-booking'),
            'is_hide'        => 0,
            'is_default'     => 1,
            'field_position' => 1,
        ),
        'firstname'     => array(
            'field_name'     => 'firstname',
            'field_type'     => 'Text',
            'is_edit'        => 0,
            'is_required'    => 0,
            'label'          => __('Firstname', 'bookingpress-appointment-booking'),
            'placeholder'    => __('Enter your firstname', 'bookingpress-appointment-booking'),
            'error_message'  => __('Please enter your firstname', 'bookingpress-appointment-booking'),
            'is_hide'        => 0,
            'is_default'     => 1,
            'field_position' => 2,
        ),
        'lastname'      => array(
            'field_name'     => 'lastname',
            'field_type'     => 'Text',
            'is_edit'        => 0,
            'is_required'    => 0,
            'label'          => __('Lastname', 'bookingpress-appointment-booking'),
            'placeholder'    => __('Enter your lastname', 'bookingpress-appointment-booking'),
            'error_message'  => __('Please enter your lastname', 'bookingpress-appointment-booking'),
            'is_hide'        => 0,
            'is_default'     => 1,
            'field_position' => 3,
        ),
        'email_address' => array(
            'field_name'     => 'email_address',
            'field_type'     => 'Email',
            'is_edit'        => 0,
            'is_required'    => true,
            'label'          => __('Email Address', 'bookingpress-appointment-booking'),
            'placeholder'    => __('Enter your email address', 'bookingpress-appointment-booking'),
            'error_message'  => __('Please enter your email address', 'bookingpress-appointment-booking'),
            'is_hide'        => 0,
            'is_default'     => 1,
            'field_position' => 4,
        ),
        'phone_number'  => array(
            'field_name'     => 'phone_number',
            'field_type'     => 'Dropdown',
            'is_edit'        => 0,
            'is_required'    => 0,
            'label'          => __('Phone Number', 'bookingpress-appointment-booking'),
            'placeholder'    => __('Enter your phone number', 'bookingpress-appointment-booking'),
            'error_message'  => __('Please enter your phone number', 'bookingpress-appointment-booking'),
            'is_hide'        => 0,
            'is_default'     => 1,
            'field_position' => 5,
        ),
        'note'          => array(
            'field_name'     => 'note',
            'field_type'     => 'Textarea',
            'is_edit'        => 0,
            'is_required'    => 0,
            'label'          => __('Note', 'bookingpress-appointment-booking'),
            'placeholder'    => __('Enter note details', 'bookingpress-appointment-booking'),
            'error_message'  => __('Please enter appointment note', 'bookingpress-appointment-booking'),
            'is_hide'        => 0,
            'is_default'     => 1,
            'field_position' => 6,
        ),
    ),
    'my_booking_field_settings'              => array(
        'mybooking_title_text'        => __('My Bookings', 'bookingpress-appointment-booking'),
        'hide_customer_details'       => false,
        'hide_search_bar'             => false,
        'allow_to_cancel_appointment' => true,
        'reset_button_title'          => __('Reset', 'bookingpress-appointment-booking'),  
        'apply_button_title'          => __('Apply', 'bookingpress-appointment-booking'),  
        'search_appointment_title'    => __('Search appointments', 'bookingpress-appointment-booking'),  
        'after_cancelled_appointment_redirection' => '',
    ),   
    'add_custom_css_modal' => false,    
    'bookigpress_form_custom_css' => '',
    'css_action' => '',
    ); 
}
